==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/rbac/v1alpha1/RbacConfigSpecFluent.java <==
package me.snowdrop.istio.api.rbac.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Boolean;

public interface RbacConfigSpecFluent<A extends RbacConfigSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExclusion instead.
 * @return The buildable object.
 */
@Deprecated public Target getExclusion();
    public Target buildExclusion();
    public A withExclusion(Target exclusion);
    public Boolean hasExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> withNewExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> withNewExclusionLike(Target item);
    public RbacConfigSpecFluent.ExclusionNested<A> editExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> editOrNewExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> editOrNewExclusionLike(Target item);
    
/**
 * This method has been deprecated, please use method buildInclusion instead.
 * @return The buildable object.
 */
@Deprecated public Target getInclusion();
    public Target buildInclusion();
    public A withInclusion(Target inclusion);
    public Boolean hasInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> withNewInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> withNewInclusionLike(Target item);
    public RbacConfigSpecFluent.InclusionNested<A> editInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> editOrNewInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> editOrNewInclusionLike(Target item);
    public me.snowdrop.istio.api.rbac.v1alpha1.Mode getMode();
    public A withMode(me.snowdrop.istio.api.rbac.v1alpha1.Mode mode);
    public Boolean hasMode();

    public interface ExclusionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetFluent<RbacConfigSpecFluent.ExclusionNested<N>>{

        
    public N and();    public N endExclusion();
}
    public interface InclusionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetFluent<RbacConfigSpecFluent.InclusionNested<N>>{

        
    public N and();    public N endInclusion();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/rbac/v1alpha1/RbacConfigSpecFluent.java <==
package me.snowdrop.istio.api.rbac.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface RbacConfigSpecFluent<A extends RbacConfigSpecFluent<A>> extends Fluent<A>{


    public EnforcementMode getEnforcementMode();
    public A withEnforcementMode(EnforcementMode enforcementMode);
    public Boolean hasEnforcementMode();
    
/**
 * This method has been deprecated, please use method buildExclusion instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.rbac.v1alpha1.Target getExclusion();
    public me.snowdrop.istio.api.rbac.v1alpha1.Target buildExclusion();
    public A withExclusion(me.snowdrop.istio.api.rbac.v1alpha1.Target exclusion);
    public Boolean hasExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> withNewExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> withNewExclusionLike(me.snowdrop.istio.api.rbac.v1alpha1.Target item);
    public RbacConfigSpecFluent.ExclusionNested<A> editExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> editOrNewExclusion();
    public RbacConfigSpecFluent.ExclusionNested<A> editOrNewExclusionLike(me.snowdrop.istio.api.rbac.v1alpha1.Target item);
    
/**
 * This method has been deprecated, please use method buildInclusion instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.rbac.v1alpha1.Target getInclusion();
    public me.snowdrop.istio.api.rbac.v1alpha1.Target buildInclusion();
    public A withInclusion(me.snowdrop.istio.api.rbac.v1alpha1.Target inclusion);
    public Boolean hasInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> withNewInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> withNewInclusionLike(me.snowdrop.istio.api.rbac.v1alpha1.Target item);
    public RbacConfigSpecFluent.InclusionNested<A> editInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> editOrNewInclusion();
    public RbacConfigSpecFluent.InclusionNested<A> editOrNewInclusionLike(me.snowdrop.istio.api.rbac.v1alpha1.Target item);
    public me.snowdrop.istio.api.rbac.v1alpha1.Mode getMode();
    public A withMode(me.snowdrop.istio.api.rbac.v1alpha1.Mode mode);
    public Boolean hasMode();

    public interface ExclusionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetFluent<RbacConfigSpecFluent.ExclusionNested<N>>{

        
    public N and();    public N endExclusion();
}
    public interface InclusionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TargetFluent<RbacConfigSpecFluent.InclusionNested<N>>{

        
    public N and();    public N endInclusion();
}


}
